Report

Go to page content

# Dexy Run Report

## Results of your Run

This is a logfile to help you understand how dexy has processed your files and to assist with troubleshooting.

### Timing

The total elapsed time for batch 1003 was 4.45 (0.07 minutes).

### Config

This is the configuration which was used for this run:

    Directory .:
    code:
        - .R|rout

    .md|jinja|pandoc:
        - code

    .md|jinja|pandoc|-odt:
        - pandoc: { ext : .odt }
        - code

    .md|jinja|pandoc|-pdf:
        - pandoc: { ext : .pdf }
        - code

    .md|jinja|pandoc|-docx:
        - pandoc: { ext : .docx }
        - code

    .md|jinja|pandoc|-epub:
        - pandoc: { ext : .epub }
        - code

# 10 Slowest Tasks

- 1.788 - example.R|rout (generated)
- 1.122 - report.md|jinja|pandoc (generated)
- 0.216 - report.md|jinja (generated)
- 0.185 - report.md|jinja|pandoc (generated)
- 0.160 - report.md|jinja|pandoc (generated)
- 0.157 - report.md|jinja|pandoc (generated)
- 0.091 - report.md|jinja|pandoc (generated)
- 0.028 - report.md|jinja (generated)
- 0.028 - report.md|jinja (generated)
- 0.026 - report.md|jinja (generated)

# Documents

## example.R|rout ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
example.R | artifacts/37efdae66ef5056d41883121456b3c86.R | 0.0001 |  |  |
example.R|rout | artifacts/db00c9d7c68b1858edb98ddfff3140fb.txt | 1.7875 | generated |  | wd

#### Document Log

    2012-11-24 13:24:45,683 - example.R|rout - DEBUG - Setting up FilterArtifact:example.R|rout::Doc:example.R|rout
    2012-11-24 13:24:45,880 - example.R|rout - DEBUG - Setting hashstring for example.R|rout to db00c9d7c68b1858edb98ddfff3140fb
    2012-11-24 13:24:45,880 - example.R|rout - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,027 - example.R|rout - DEBUG - Running FilterArtifact:example.R|rout::Doc:example.R|rout
    2012-11-24 13:24:46,028 - example.R|rout - DEBUG - Output is not cached under db00c9d7c68b1858edb98ddfff3140fb, running...
    2012-11-24 13:24:46,030 - example.R|rout - DEBUG - setting up wd for example.R|rout. exists already: artifacts/db00c9d7c68b1858edb98ddfff3140fb/
    2012-11-24 13:24:46,054 - example.R|rout - DEBUG - about to run 'R CMD BATCH --vanilla --quiet --slave --no-timing  example.R  example.txt' in 'artifacts/db00c9d7c68b1858edb98ddfff3140fb/'
    2012-11-24 13:24:47,796 - example.R|rout - DEBUG - stdout is ''
    2012-11-24 13:24:47,797 - example.R|rout - DEBUG - stderr is ''
    2012-11-24 13:24:47,798 - example.R|rout - DEBUG - adding new files found in artifacts/db00c9d7c68b1858edb98ddfff3140fb for example.R|rout
    2012-11-24 13:24:47,800 - example.R|rout - DEBUG - adding additional doc example.txt (created by example.R|rout)
    2012-11-24 13:24:47,804 - example.R|rout - DEBUG - adding additional doc plot.png (created by example.R|rout)
    2012-11-24 13:24:47,813 - example.R|rout - DEBUG - adding additional doc storage.json (created by example.R|rout)

## report.md|jinja|pandoc ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/3b51ad54d83e46c731e15d04028b1298.md | 0.2155 | generated |  | wd
report.md|jinja|pandoc | artifacts/56ee4f9438b2be075327e5126137ce95.html | 0.0911 | generated |  | wd

#### Document Log

    2012-11-24 13:24:45,884 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,885 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,913 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:24:45,914 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,918 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,920 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:45,921 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,921 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,935 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:24:45,936 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,943 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,946 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:45,947 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,948 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,965 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:24:45,967 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,974 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,977 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:45,978 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,979 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,994 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:24:45,995 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,003 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,004 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:46,005 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,005 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,019 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:24:46,020 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:47,815 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - Output is not cached under 3b51ad54d83e46c731e15d04028b1298, running...
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/3b51ad54d83e46c731e15d04028b1298/
    2012-11-24 13:24:47,967 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/3b51ad54d83e46c731e15d04028b1298/, artifacts/3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:47,971 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,027 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,030 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Output is not cached under 56ee4f9438b2be075327e5126137ce95, running...
    2012-11-24 13:24:48,032 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/56ee4f9438b2be075327e5126137ce95/
    2012-11-24 13:24:48,033 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.html' in 'artifacts/56ee4f9438b2be075327e5126137ce95/'
    2012-11-24 13:24:48,118 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,120 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,125 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,127 - report.md|jinja - DEBUG - Output is not cached under d781adeca229bf3c204d4559e7142f82, running...
    2012-11-24 13:24:48,128 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/d781adeca229bf3c204d4559e7142f82/
    2012-11-24 13:24:48,129 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/d781adeca229bf3c204d4559e7142f82/, artifacts/d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,151 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,153 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5e3fd51d5ca109fcd8ea025ec8812a58, running...
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/
    2012-11-24 13:24:48,155 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.odt' in 'artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/'
    2012-11-24 13:24:48,307 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,308 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,315 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,316 - report.md|jinja - DEBUG - Output is not cached under 268ddcdbbb07b992279bfee51f3fc10a, running...
    2012-11-24 13:24:48,317 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/268ddcdbbb07b992279bfee51f3fc10a/
    2012-11-24 13:24:48,320 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/268ddcdbbb07b992279bfee51f3fc10a/, artifacts/268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,339 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,343 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Output is not cached under b27f64993498e575dfb34cb451b98a60, running...
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/b27f64993498e575dfb34cb451b98a60/
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/b27f64993498e575dfb34cb451b98a60/'
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Output is not cached under b93ce2270e0bca12beabeb94273e155c, running...
    2012-11-24 13:24:48,531 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/b93ce2270e0bca12beabeb94273e155c/
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/b93ce2270e0bca12beabeb94273e155c/, artifacts/b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,535 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,551 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,555 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Output is not cached under 9a2ebc0b68c10b24f3373072e135983a, running...
    2012-11-24 13:24:48,557 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/9a2ebc0b68c10b24f3373072e135983a/
    2012-11-24 13:24:48,558 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.pdf' in 'artifacts/9a2ebc0b68c10b24f3373072e135983a/'
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Output is not cached under f143a1cc23ee4ca0350b69101644bfe2, running...
    2012-11-24 13:24:49,680 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/f143a1cc23ee4ca0350b69101644bfe2/
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/f143a1cc23ee4ca0350b69101644bfe2/, artifacts/f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:49,704 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5a19c3f5c58a1f5da222674b87c237ed, running...
    2012-11-24 13:24:49,706 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5a19c3f5c58a1f5da222674b87c237ed/
    2012-11-24 13:24:49,707 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.docx' in 'artifacts/5a19c3f5c58a1f5da222674b87c237ed/'
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stderr is ''

## report.md|jinja|pandoc|-odt ↑

#### Arguments

    pandoc:
        ext: .odt

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0001 |  |  |
report.md|jinja | artifacts/d781adeca229bf3c204d4559e7142f82.md | 0.0281 | generated |  | wd
report.md|jinja|pandoc | artifacts/5e3fd51d5ca109fcd8ea025ec8812a58.odt | 0.1566 | generated |  | wd
report.md|jinja|pandoc|-odt | artifacts/abc9513aa869aba5c54d4f7bd5fb212a.odt | 0.0015 | generated |  |

#### Document Log

    2012-11-24 13:24:45,884 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,885 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,913 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:24:45,914 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,918 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,920 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:45,921 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,921 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,935 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:24:45,936 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,938 - report.md|jinja|pandoc|-odt - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-odt::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,940 - report.md|jinja|pandoc|-odt - DEBUG - Setting hashstring for report.md|jinja|pandoc|-odt to abc9513aa869aba5c54d4f7bd5fb212a
    2012-11-24 13:24:45,940 - report.md|jinja|pandoc|-odt - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,943 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,946 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:45,947 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,948 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,965 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:24:45,967 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,974 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,977 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:45,978 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,979 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,994 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:24:45,995 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,003 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,004 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:46,005 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,005 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,019 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:24:46,020 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:47,815 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - Output is not cached under 3b51ad54d83e46c731e15d04028b1298, running...
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/3b51ad54d83e46c731e15d04028b1298/
    2012-11-24 13:24:47,967 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/3b51ad54d83e46c731e15d04028b1298/, artifacts/3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:47,971 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,027 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,030 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Output is not cached under 56ee4f9438b2be075327e5126137ce95, running...
    2012-11-24 13:24:48,032 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/56ee4f9438b2be075327e5126137ce95/
    2012-11-24 13:24:48,033 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.html' in 'artifacts/56ee4f9438b2be075327e5126137ce95/'
    2012-11-24 13:24:48,118 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,120 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,125 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,127 - report.md|jinja - DEBUG - Output is not cached under d781adeca229bf3c204d4559e7142f82, running...
    2012-11-24 13:24:48,128 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/d781adeca229bf3c204d4559e7142f82/
    2012-11-24 13:24:48,129 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/d781adeca229bf3c204d4559e7142f82/, artifacts/d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,151 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,153 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5e3fd51d5ca109fcd8ea025ec8812a58, running...
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/
    2012-11-24 13:24:48,155 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.odt' in 'artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/'
    2012-11-24 13:24:48,307 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,308 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,311 - report.md|jinja|pandoc|-odt - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-odt::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,312 - report.md|jinja|pandoc|-odt - DEBUG - Output is not cached under abc9513aa869aba5c54d4f7bd5fb212a, running...
    2012-11-24 13:24:48,315 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,316 - report.md|jinja - DEBUG - Output is not cached under 268ddcdbbb07b992279bfee51f3fc10a, running...
    2012-11-24 13:24:48,317 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/268ddcdbbb07b992279bfee51f3fc10a/
    2012-11-24 13:24:48,320 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/268ddcdbbb07b992279bfee51f3fc10a/, artifacts/268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,339 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,343 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Output is not cached under b27f64993498e575dfb34cb451b98a60, running...
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/b27f64993498e575dfb34cb451b98a60/
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/b27f64993498e575dfb34cb451b98a60/'
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Output is not cached under b93ce2270e0bca12beabeb94273e155c, running...
    2012-11-24 13:24:48,531 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/b93ce2270e0bca12beabeb94273e155c/
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/b93ce2270e0bca12beabeb94273e155c/, artifacts/b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,535 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,551 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,555 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Output is not cached under 9a2ebc0b68c10b24f3373072e135983a, running...
    2012-11-24 13:24:48,557 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/9a2ebc0b68c10b24f3373072e135983a/
    2012-11-24 13:24:48,558 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.pdf' in 'artifacts/9a2ebc0b68c10b24f3373072e135983a/'
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Output is not cached under f143a1cc23ee4ca0350b69101644bfe2, running...
    2012-11-24 13:24:49,680 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/f143a1cc23ee4ca0350b69101644bfe2/
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/f143a1cc23ee4ca0350b69101644bfe2/, artifacts/f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:49,704 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5a19c3f5c58a1f5da222674b87c237ed, running...
    2012-11-24 13:24:49,706 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5a19c3f5c58a1f5da222674b87c237ed/
    2012-11-24 13:24:49,707 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.docx' in 'artifacts/5a19c3f5c58a1f5da222674b87c237ed/'
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stderr is ''

## report.md|jinja|pandoc|-epub ↑

#### Arguments

    pandoc:
        ext: .epub

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0001 |  |  |
report.md|jinja | artifacts/268ddcdbbb07b992279bfee51f3fc10a.md | 0.0282 | generated |  | wd
report.md|jinja|pandoc | artifacts/b27f64993498e575dfb34cb451b98a60.epub | 0.1849 | generated |  | wd
report.md|jinja|pandoc|-epub | artifacts/9f6b0ac9c642cc52dcb00a5996eec4ba.epub | 0.0004 | generated |  |

#### Document Log

    2012-11-24 13:24:45,884 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,885 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,913 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:24:45,914 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,918 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,920 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:45,921 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,921 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,935 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:24:45,936 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,943 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,946 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:45,947 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,948 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,965 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:24:45,967 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,968 - report.md|jinja|pandoc|-epub - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-epub::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,970 - report.md|jinja|pandoc|-epub - DEBUG - Setting hashstring for report.md|jinja|pandoc|-epub to 9f6b0ac9c642cc52dcb00a5996eec4ba
    2012-11-24 13:24:45,971 - report.md|jinja|pandoc|-epub - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,974 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,977 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:45,978 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,979 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,994 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:24:45,995 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,003 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,004 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:46,005 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,005 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,019 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:24:46,020 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:47,815 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - Output is not cached under 3b51ad54d83e46c731e15d04028b1298, running...
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/3b51ad54d83e46c731e15d04028b1298/
    2012-11-24 13:24:47,967 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/3b51ad54d83e46c731e15d04028b1298/, artifacts/3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:47,971 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,027 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,030 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Output is not cached under 56ee4f9438b2be075327e5126137ce95, running...
    2012-11-24 13:24:48,032 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/56ee4f9438b2be075327e5126137ce95/
    2012-11-24 13:24:48,033 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.html' in 'artifacts/56ee4f9438b2be075327e5126137ce95/'
    2012-11-24 13:24:48,118 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,120 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,125 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,127 - report.md|jinja - DEBUG - Output is not cached under d781adeca229bf3c204d4559e7142f82, running...
    2012-11-24 13:24:48,128 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/d781adeca229bf3c204d4559e7142f82/
    2012-11-24 13:24:48,129 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/d781adeca229bf3c204d4559e7142f82/, artifacts/d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,151 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,153 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5e3fd51d5ca109fcd8ea025ec8812a58, running...
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/
    2012-11-24 13:24:48,155 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.odt' in 'artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/'
    2012-11-24 13:24:48,307 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,308 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,315 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,316 - report.md|jinja - DEBUG - Output is not cached under 268ddcdbbb07b992279bfee51f3fc10a, running...
    2012-11-24 13:24:48,317 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/268ddcdbbb07b992279bfee51f3fc10a/
    2012-11-24 13:24:48,320 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/268ddcdbbb07b992279bfee51f3fc10a/, artifacts/268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,339 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,343 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Output is not cached under b27f64993498e575dfb34cb451b98a60, running...
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/b27f64993498e575dfb34cb451b98a60/
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/b27f64993498e575dfb34cb451b98a60/'
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,529 - report.md|jinja|pandoc|-epub - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-epub::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,529 - report.md|jinja|pandoc|-epub - DEBUG - Output is not cached under 9f6b0ac9c642cc52dcb00a5996eec4ba, running...
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Output is not cached under b93ce2270e0bca12beabeb94273e155c, running...
    2012-11-24 13:24:48,531 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/b93ce2270e0bca12beabeb94273e155c/
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/b93ce2270e0bca12beabeb94273e155c/, artifacts/b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,535 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,551 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,555 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Output is not cached under 9a2ebc0b68c10b24f3373072e135983a, running...
    2012-11-24 13:24:48,557 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/9a2ebc0b68c10b24f3373072e135983a/
    2012-11-24 13:24:48,558 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.pdf' in 'artifacts/9a2ebc0b68c10b24f3373072e135983a/'
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Output is not cached under f143a1cc23ee4ca0350b69101644bfe2, running...
    2012-11-24 13:24:49,680 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/f143a1cc23ee4ca0350b69101644bfe2/
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/f143a1cc23ee4ca0350b69101644bfe2/, artifacts/f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:49,704 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5a19c3f5c58a1f5da222674b87c237ed, running...
    2012-11-24 13:24:49,706 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5a19c3f5c58a1f5da222674b87c237ed/
    2012-11-24 13:24:49,707 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.docx' in 'artifacts/5a19c3f5c58a1f5da222674b87c237ed/'
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stderr is ''

## report.md|jinja|pandoc|-pdf ↑

#### Arguments

    pandoc:
        ext: .pdf

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/b93ce2270e0bca12beabeb94273e155c.md | 0.0255 | generated |  | wd
report.md|jinja|pandoc | artifacts/9a2ebc0b68c10b24f3373072e135983a.pdf | 1.1220 | generated |  | wd
report.md|jinja|pandoc|-pdf | artifacts/dd20b3681eff2a48ec03888ef2adfc12.pdf | 0.0004 | generated |  |

#### Document Log

    2012-11-24 13:24:45,884 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,885 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,913 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:24:45,914 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,918 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,920 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:45,921 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,921 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,935 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:24:45,936 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,943 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,946 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:45,947 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,948 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,965 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:24:45,967 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,974 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,977 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:45,978 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,979 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,994 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:24:45,995 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,997 - report.md|jinja|pandoc|-pdf - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-pdf::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,999 - report.md|jinja|pandoc|-pdf - DEBUG - Setting hashstring for report.md|jinja|pandoc|-pdf to dd20b3681eff2a48ec03888ef2adfc12
    2012-11-24 13:24:45,999 - report.md|jinja|pandoc|-pdf - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,003 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,004 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:46,005 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,005 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,019 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:24:46,020 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:47,815 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - Output is not cached under 3b51ad54d83e46c731e15d04028b1298, running...
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/3b51ad54d83e46c731e15d04028b1298/
    2012-11-24 13:24:47,967 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/3b51ad54d83e46c731e15d04028b1298/, artifacts/3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:47,971 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,027 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,030 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Output is not cached under 56ee4f9438b2be075327e5126137ce95, running...
    2012-11-24 13:24:48,032 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/56ee4f9438b2be075327e5126137ce95/
    2012-11-24 13:24:48,033 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.html' in 'artifacts/56ee4f9438b2be075327e5126137ce95/'
    2012-11-24 13:24:48,118 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,120 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,125 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,127 - report.md|jinja - DEBUG - Output is not cached under d781adeca229bf3c204d4559e7142f82, running...
    2012-11-24 13:24:48,128 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/d781adeca229bf3c204d4559e7142f82/
    2012-11-24 13:24:48,129 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/d781adeca229bf3c204d4559e7142f82/, artifacts/d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,151 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,153 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5e3fd51d5ca109fcd8ea025ec8812a58, running...
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/
    2012-11-24 13:24:48,155 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.odt' in 'artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/'
    2012-11-24 13:24:48,307 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,308 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,315 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,316 - report.md|jinja - DEBUG - Output is not cached under 268ddcdbbb07b992279bfee51f3fc10a, running...
    2012-11-24 13:24:48,317 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/268ddcdbbb07b992279bfee51f3fc10a/
    2012-11-24 13:24:48,320 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/268ddcdbbb07b992279bfee51f3fc10a/, artifacts/268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,339 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,343 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Output is not cached under b27f64993498e575dfb34cb451b98a60, running...
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/b27f64993498e575dfb34cb451b98a60/
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/b27f64993498e575dfb34cb451b98a60/'
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Output is not cached under b93ce2270e0bca12beabeb94273e155c, running...
    2012-11-24 13:24:48,531 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/b93ce2270e0bca12beabeb94273e155c/
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/b93ce2270e0bca12beabeb94273e155c/, artifacts/b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,535 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,551 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,555 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Output is not cached under 9a2ebc0b68c10b24f3373072e135983a, running...
    2012-11-24 13:24:48,557 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/9a2ebc0b68c10b24f3373072e135983a/
    2012-11-24 13:24:48,558 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.pdf' in 'artifacts/9a2ebc0b68c10b24f3373072e135983a/'
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:49,678 - report.md|jinja|pandoc|-pdf - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-pdf::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:49,678 - report.md|jinja|pandoc|-pdf - DEBUG - Output is not cached under dd20b3681eff2a48ec03888ef2adfc12, running...
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Output is not cached under f143a1cc23ee4ca0350b69101644bfe2, running...
    2012-11-24 13:24:49,680 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/f143a1cc23ee4ca0350b69101644bfe2/
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/f143a1cc23ee4ca0350b69101644bfe2/, artifacts/f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:49,704 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5a19c3f5c58a1f5da222674b87c237ed, running...
    2012-11-24 13:24:49,706 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5a19c3f5c58a1f5da222674b87c237ed/
    2012-11-24 13:24:49,707 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.docx' in 'artifacts/5a19c3f5c58a1f5da222674b87c237ed/'
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stderr is ''

## report.md|jinja|pandoc|-docx ↑

#### Arguments

    pandoc:
        ext: .docx

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/f143a1cc23ee4ca0350b69101644bfe2.md | 0.0256 | generated |  | wd
report.md|jinja|pandoc | artifacts/5a19c3f5c58a1f5da222674b87c237ed.docx | 0.1601 | generated |  | wd
report.md|jinja|pandoc|-docx | artifacts/de75484514388939aa97dd3f00993cb4.docx | 0.0010 | generated |  |

#### Document Log

    2012-11-24 13:24:45,884 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:45,885 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,885 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:45,913 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:24:45,914 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,918 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,920 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:45,921 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,921 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:45,935 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:24:45,936 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,943 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,946 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:45,947 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,948 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:45,965 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:24:45,967 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,974 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,977 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:45,978 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:45,979 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:45,994 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:24:45,995 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,003 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,004 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:46,005 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,005 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,019 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:24:46,020 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:46,022 - report.md|jinja|pandoc|-docx - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-docx::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:46,024 - report.md|jinja|pandoc|-docx - DEBUG - Setting hashstring for report.md|jinja|pandoc|-docx to de75484514388939aa97dd3f00993cb4
    2012-11-24 13:24:46,024 - report.md|jinja|pandoc|-docx - DEBUG - setting up output data of class GenericData
    2012-11-24 13:24:47,815 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - Output is not cached under 3b51ad54d83e46c731e15d04028b1298, running...
    2012-11-24 13:24:47,816 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/3b51ad54d83e46c731e15d04028b1298/
    2012-11-24 13:24:47,967 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/3b51ad54d83e46c731e15d04028b1298/, artifacts/3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:47,968 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:47,969 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:47,970 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:47,971 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,025 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,026 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,027 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,030 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:24:48,031 - report.md|jinja|pandoc - DEBUG - Output is not cached under 56ee4f9438b2be075327e5126137ce95, running...
    2012-11-24 13:24:48,032 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/56ee4f9438b2be075327e5126137ce95/
    2012-11-24 13:24:48,033 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.html' in 'artifacts/56ee4f9438b2be075327e5126137ce95/'
    2012-11-24 13:24:48,118 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,120 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,125 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,127 - report.md|jinja - DEBUG - Output is not cached under d781adeca229bf3c204d4559e7142f82, running...
    2012-11-24 13:24:48,128 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/d781adeca229bf3c204d4559e7142f82/
    2012-11-24 13:24:48,129 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/d781adeca229bf3c204d4559e7142f82/, artifacts/d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,130 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,131 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,132 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,149 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,150 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,151 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,153 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5e3fd51d5ca109fcd8ea025ec8812a58, running...
    2012-11-24 13:24:48,154 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/
    2012-11-24 13:24:48,155 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.odt' in 'artifacts/5e3fd51d5ca109fcd8ea025ec8812a58/'
    2012-11-24 13:24:48,307 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,308 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,315 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,316 - report.md|jinja - DEBUG - Output is not cached under 268ddcdbbb07b992279bfee51f3fc10a, running...
    2012-11-24 13:24:48,317 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/268ddcdbbb07b992279bfee51f3fc10a/
    2012-11-24 13:24:48,320 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/268ddcdbbb07b992279bfee51f3fc10a/, artifacts/268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,321 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,322 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,323 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,339 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,340 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,341 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,343 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:24:48,344 - report.md|jinja|pandoc - DEBUG - Output is not cached under b27f64993498e575dfb34cb451b98a60, running...
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/b27f64993498e575dfb34cb451b98a60/
    2012-11-24 13:24:48,345 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/b27f64993498e575dfb34cb451b98a60/'
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:48,528 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,530 - report.md|jinja - DEBUG - Output is not cached under b93ce2270e0bca12beabeb94273e155c, running...
    2012-11-24 13:24:48,531 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/b93ce2270e0bca12beabeb94273e155c/
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/b93ce2270e0bca12beabeb94273e155c/, artifacts/b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:48,532 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:48,533 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:48,534 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:48,535 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:48,551 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:48,552 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:48,553 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:48,555 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:24:48,556 - report.md|jinja|pandoc - DEBUG - Output is not cached under 9a2ebc0b68c10b24f3373072e135983a, running...
    2012-11-24 13:24:48,557 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/9a2ebc0b68c10b24f3373072e135983a/
    2012-11-24 13:24:48,558 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.pdf' in 'artifacts/9a2ebc0b68c10b24f3373072e135983a/'
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,677 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,679 - report.md|jinja - DEBUG - Output is not cached under f143a1cc23ee4ca0350b69101644bfe2, running...
    2012-11-24 13:24:49,680 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/f143a1cc23ee4ca0350b69101644bfe2/
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/f143a1cc23ee4ca0350b69101644bfe2/, artifacts/f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:24:49,681 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:24:49,682 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:24:49,683 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:24:49,701 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:24:49,702 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:24:49,704 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,705 - report.md|jinja|pandoc - DEBUG - Output is not cached under 5a19c3f5c58a1f5da222674b87c237ed, running...
    2012-11-24 13:24:49,706 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/5a19c3f5c58a1f5da222674b87c237ed/
    2012-11-24 13:24:49,707 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.docx' in 'artifacts/5a19c3f5c58a1f5da222674b87c237ed/'
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:24:49,834 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:24:49,866 - report.md|jinja|pandoc|-docx - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-docx::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:24:49,866 - report.md|jinja|pandoc|-docx - DEBUG - Output is not cached under de75484514388939aa97dd3f00993cb4, running...

## example.txt ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
example.txt | artifacts/67ca147287010eee7af5529b040a79ab.txt | 0.0000 |  |  |

#### Document Log

    2012-11-24 13:24:47,801 - example.txt - DEBUG - Setting up InitialVirtualArtifact:example.txt::Doc:example.txt
    2012-11-24 13:24:47,802 - example.txt - DEBUG - Setting hashstring for example.txt to 67ca147287010eee7af5529b040a79ab
    2012-11-24 13:24:47,803 - example.txt - DEBUG - setting up output data of class GenericData

## plot.png ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
plot.png | artifacts/2fcd6e22786b435da431867dbef1647e.png | 0.0000 |  |  |

#### Document Log

    2012-11-24 13:24:47,805 - plot.png - DEBUG - Setting up InitialVirtualArtifact:plot.png::Doc:plot.png
    2012-11-24 13:24:47,805 - plot.png - DEBUG - Setting hashstring for plot.png to 2fcd6e22786b435da431867dbef1647e
    2012-11-24 13:24:47,813 - plot.png - DEBUG - setting up output data of class GenericData

## storage.json ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
storage.json | artifacts/dcebc4433e4a66776a1573a5bc232c98.json | 0.0000 |  |  |

#### Document Log

    2012-11-24 13:24:47,814 - storage.json - DEBUG - Setting up InitialVirtualArtifact:storage.json::Doc:storage.json
    2012-11-24 13:24:47,814 - storage.json - DEBUG - Setting hashstring for storage.json to dcebc4433e4a66776a1573a5bc232c98
    2012-11-24 13:24:47,814 - storage.json - DEBUG - setting up output data of class GenericData